@@ -2,6 +2,7 @@
 
 import re
 
+from .auth_token_provider import AuthTokenProvider, AuthTokenProviderFactory
 from ..exceptions import RefreshTokenException
 from ..http_request import RequestDetails, WebClient
 from ..http_request.http_method import HttpMethod
@@ -11,7 +12,7 @@ _timeout = 20
 _url = 'https://twitter.com'
 
 
-class TwitterAuthTokenProvider:
+class TwitterAuthTokenProvider(AuthTokenProvider):
     """Class to manage Twitter token api."""
 
     web_client: WebClient
@@ -30,7 +31,7 @@ class TwitterAuthTokenProvider:
         else:
             raise RefreshTokenException('Error during request for token')
 
-    def refresh(self) -> str:
+    def get_new_token(self) -> str:
         """Method to get refreshed token. In case of error raise RefreshTokenException."""
         token_html = self._request_for_response_body()
         match = re.search(r'\("gt=(\d+);', token_html)
@@ -40,3 +41,11 @@ class TwitterAuthTokenProvider:
             print('Could not find the Guest token in HTML')
             print(token_html)
             raise RefreshTokenException('Could not find the Guest token in HTML')
+
+
+class TwitterAuthTokenProviderFactory(AuthTokenProviderFactory):
+    """Provider of TwitterAuthTokenProviderFactory."""
+
+    def create(self, web_client: WebClient) -> AuthTokenProvider:
+        """Method to create TwitterAuthTokenProvider from web_client."""
+        return TwitterAuthTokenProvider(web_client)
